<?php

namespace Drupal\membership_offer;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\Core\Entity\EntityPublishedInterface;
use Drupal\membership_commerce\PurchasableMembershipInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining Membership Offer entities.
 *
 * @ingroup membership
 */
interface MembershipOfferInterface extends PurchasableMembershipInterface, EntityChangedInterface, EntityOwnerInterface, EntityPublishedInterface, ContentEntityInterface {

  /**
   * Gets the Membership Offer name.
   *
   * @return string
   *   Name of the Membership Offer.
   */
  public function getName();

  /**
   * Sets the Membership Offer name.
   *
   * @param string $name
   *   The Membership Offer name.
   *
   * @return \Drupal\membership_offer\MembershipOfferInterface
   *   The called Membership Offer entity.
   */
  public function setName($name);

  /**
   * Gets the Membership Offer creation timestamp.
   *
   * @return int
   *   Creation timestamp of the Membership Offer.
   */
  public function getCreatedTime();

  /**
   * Sets the Membership Offer creation timestamp.
   *
   * @param int $timestamp
   *   The Membership Offer creation timestamp.
   *
   * @return \Drupal\membership_offer\MembershipOfferInterface
   *   The called Membership Offer entity.
   */
  public function setCreatedTime($timestamp);

}
